@@ -1,4 +1,4 @@
-#!perl
+#!perl ## no critic (TidyCode)
 
 use strict;
 use warnings;
@@ -28,26 +28,26 @@ my $htc;
     local $HTML::Template::Compiled::Filter::Whitespace::DEBUG = 1;
     $htc = HTML::Template::Compiled->new(
         tagstyle  => [qw(-classic -comment +asp)],
-        filter    => get_whitespace_filter(),
+        filter    => get_whitespace_filter,
         scalarref => \$template,
     );
 }
 $htc->param(param => "parameter \n \n         param");
 () = print "Filter swichted temporary off.\n",
       "------------------------------\n",
-      $htc->output(),
+      $htc->output,
       "\n";
 
 $htc = HTML::Template::Compiled->new(
-    tagstyle  => [qw(-classic -comment +asp)],
-    filter    => get_whitespace_filter(),
+    tagstyle  => [ qw( -classic -comment +asp ) ],
+    filter    => get_whitespace_filter,
     scalarref => \$template,
 );
 
 $htc->param(param => "parameter \n \n         param");
 () = print "filtered\n",
       "--------\n",
-      $htc->output(),
+      $htc->output,
       "\n";
 
-# $Id$
\ No newline at end of file
+# $Id$
